==> noctalia-3.7.0-1-x86_64.pkg.tar.zst: etc/xdg/quickshell/noctalia-shell/CREDITS.md <==
# Credits

Noctalia Shell is made possible by the incredible work of many open-source projects and contributors.

## Design & Branding

- **MrDowntempo** - Creator of the Noctalia Owl and moon logo
- **[SaberJ2X](https://www.reddit.com/user/SaberJ64/)** - Creator of Talia, the Noctalia mascot

## Core Framework

- **[Quickshell](https://github.com/outfoxxed/quickshell)** - The Qt/QML-based Wayland shell framework that powers Noctalia

## Runtime Dependencies

### System Integration
- **[brightnessctl](https://github.com/Hummer12007/brightnessctl)** - Screen brightness control
- **[wlsunset](https://sr.ht/~kennylevinsen/wlsunset/)** - Night light and blue light filter support
- **[wl-clipboard](https://github.com/bugaevc/wl-clipboard)** - Wayland clipboard utilities
- **[ddcutil](https://www.ddcutil.com/)** - External display brightness control
- **[power-profiles-daemon](https://gitlab.freedesktop.org/upower/power-profiles-daemon)** - Power profile management

### Media & Audio
- **[gpu-screen-recorder](https://git.dec05eba.com/gpu-screen-recorder/about/)** - Hardware-accelerated screen recording
- **[Cava](https://github.com/karlstav/cava)** - Audio visualizer component

### Theming & Appearance
- **[Matugen](https://github.com/InioX/matugen)** - Material You color scheme generation from wallpapers

### Utilities
- **[cliphist](https://github.com/sentriz/cliphist)** - Clipboard history support

## Audio Assets
- **[Universfield on Pixabay](https://pixabay.com/users/universfield-28281460/)** - Notification sound effect
- **[DrNI on Freesound](https://freesound.org/people/DrNI/sounds/34562/)** - Timer's alarm sound effect


## Special Thanks
- The **Wayland** community for building the future of Linux desktop graphics
- The **Niri**, **Hyprland**, **Sway**, and **MangoWC** teams for their excellent Wayland compositors
- All the contributors and users who have helped make Noctalia better

## License
Noctalia Shell is licensed under the MIT License. See [LICENSE](LICENSE) for details.

Each dependency listed above is governed by its own respective license. Please refer to their individual projects for licensing information.

==> noctalia-4.4.0-1-x86_64.pkg.tar.zst: etc/xdg/quickshell/noctalia-shell/CREDITS.md <==
# Credits

Noctalia Shell is made possible by the incredible work of many open-source projects and contributors.

## Design & Branding

- **MrDowntempo** - Creator of the Noctalia Owl and moon logo
- **[SaberJ2X](https://www.reddit.com/user/SaberJ64/)** - Creator of Talia, the Noctalia mascot

## Core Framework

- **[Quickshell](https://github.com/outfoxxed/quickshell)** - The Qt/QML-based Wayland shell framework that powers Noctalia

## Runtime Dependencies

### System Integration
- **[brightnessctl](https://github.com/Hummer12007/brightnessctl)** - Screen brightness control
- **[wlsunset](https://sr.ht/~kennylevinsen/wlsunset/)** - Night light and blue light filter support
- **[wl-clipboard](https://github.com/bugaevc/wl-clipboard)** - Wayland clipboard utilities
- **[ddcutil](https://www.ddcutil.com/)** - External display brightness control
- **[power-profiles-daemon](https://gitlab.freedesktop.org/upower/power-profiles-daemon)** - Power profile management

### Media & Audio
- **[gpu-screen-recorder](https://git.dec05eba.com/gpu-screen-recorder/about/)** - Hardware-accelerated screen recording
- **[Cava](https://github.com/karlstav/cava)** - Audio visualizer component

### Utilities
- **[cliphist](https://github.com/sentriz/cliphist)** - Clipboard history support

## Audio Assets
- **[Universfield on Pixabay](https://pixabay.com/users/universfield-28281460/)** - Notification sound effect
- **[DrNI on Freesound](https://freesound.org/people/DrNI/sounds/34562/)** - Timer's alarm sound effect
- **[Lucas McCallister on Freesound](http://www.freesound.org/samplesViewSingle.php?id=67091)** - Volume change feedback sound effect


## Special Thanks
- The **Wayland** community for building the future of Linux desktop graphics
- The **Niri**, **Hyprland**, **Sway**, and **MangoWC** teams for their excellent Wayland compositors
- All the contributors and users who have helped make Noctalia better

## License
Noctalia Shell is licensed under the MIT License. See [LICENSE](LICENSE) for details.

Each dependency listed above is governed by its own respective license. Please refer to their individual projects for licensing information.
